# -*- coding: utf-8 -*-

__version__ = '0.1.0'
__author__  = 'Adriano Margarin'
__licence__ = 'MIT'

from cpf_cnpj import Cpf, Cnpj